%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% ekli

%% IDENTIFICATION
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{PSP}[01/11/2021 Provided by Pivot Science Publication]

 %% PRELIMINARY DECLARATIONS
\LoadClass[11pt,a4paper]{article}
\RequirePackage[sfdefault]{noto} %% using Noto Sans font
\RequirePackage{ulem} %% different type undline
\RequirePackage[T1]{fontenc}
\RequirePackage[utf8]{inputenc}
\RequirePackage{calc}
%\RequirePackage{indentfirst}
\RequirePackage{fancyhdr}
\RequirePackage{graphicx,epstopdf}
\RequirePackage{lastpage}
\RequirePackage{ifthen}
\RequirePackage{lineno}
\RequirePackage{float}
\RequirePackage{amsmath}
\RequirePackage{amssymb} % For math environment bold format
\RequirePackage{setspace}
\RequirePackage{enumitem}
\RequirePackage{mathpazo}
\RequirePackage{booktabs} % For \toprule etc. in tables
\RequirePackage{titlesec}
\RequirePackage{etoolbox} % For \AtBeginDocument etc.
\RequirePackage{tabto} % To use tab for alignment on first page
\RequirePackage{xcolor, colortbl} % To provide color for soul (for english editing), for adding cell color of table
\RequirePackage{soul} % To highlight text
\newcommand{\highlighting}[1]{\colorbox{yellow}{#1}}
\RequirePackage{multirow}
\RequirePackage{microtype} % For command \textls[]{}
\RequirePackage{tikz} % For \foreach used for Orcid icon
\RequirePackage{totcount} % To enable extracting the value of the counter "page" 
\RequirePackage{changepage} % To adjust the width of the column for the title part
\RequirePackage{paracol} % For left column on first page
\RequirePackage{attrib} % For XML2PDF use \tag{} for equation
\RequirePackage{upgreek} % For making greek letters not italic
\RequirePackage{array} % For table array
\RequirePackage{tabularx}
\RequirePackage{pbox} % For biography environment
\RequirePackage{ragged2e} % For command \justifying

%% OPTIONS
% For transition period to change back to continuous page numbers
\def\@continuouspages{}
\newcommand{\continuouspages}[1]{\gdef\@continuouspages{#1}}

%% To choose the journal
% All journals (website name, full name, short name, DOI abbreviation, and ISSN + choice of continuous page numbers) are defined in an extra file. 
\input{journalinfo}


\DeclareOption{journal}{\ClassWarning{Psp}{You used an invalid journal name or you have not specified the journal. The first option of the documentclass command specifies the journal. The word 'journal' should be replaced by one of the journal names specified in template.tex (in the comment 'Choose between the following PSP journal').}} 

%% To choose the type of manuscript
\DeclareOption{abstract}{\gdef\@arttype{Abstract}}
\DeclareOption{addendum}{\gdef\@arttype{Addendum}}
\DeclareOption{Research}{\gdef\@arttype{Original Research}}
\DeclareOption{book}{\gdef\@arttype{Book}}
\DeclareOption{bookreview}{\gdef\@arttype{Book Review}}
\DeclareOption{briefreport}{\gdef\@arttype{Brief Report}}
\DeclareOption{casereport}{\gdef\@arttype{Case Report}}
\DeclareOption{comment}{\gdef\@arttype{Comment}}
\DeclareOption{commentary}{\gdef\@arttype{Commentary}}
\DeclareOption{communication}{\gdef\@arttype{Communication}}
\DeclareOption{conferenceproceedings}{\gdef\@arttype{Proceedings}}
\DeclareOption{correction}{\gdef\@arttype{Correction}}
\DeclareOption{conferencereport}{\gdef\@arttype{Conference Report}}
\DeclareOption{entry}{\gdef\@arttype{Entry}}
\DeclareOption{expressionofconcern}{\gdef\@arttype{Expression of Concern}}
\DeclareOption{extendedabstract}{\gdef\@arttype{Extended Abstract}}
\DeclareOption{datadescriptor}{\gdef\@arttype{Data Descriptor}}
\DeclareOption{editorial}{\gdef\@arttype{Editorial}}
\DeclareOption{essay}{\gdef\@arttype{Essay}}
\DeclareOption{erratum}{\gdef\@arttype{Erratum}}
\DeclareOption{hypothesis}{\gdef\@arttype{Hypothesis}}
\DeclareOption{interestingimages}{\gdef\@arttype{Interesting Images}}
\DeclareOption{letter}{\gdef\@arttype{Letter to Editor}}
\DeclareOption{obituary}{\gdef\@arttype{Obituary}}
\DeclareOption{opinion}{\gdef\@arttype{Opinion}}
\DeclareOption{Perspective}{\gdef\@arttype{Perspective}}
\DeclareOption{projectreport}{\gdef\@arttype{Project Report}}
\DeclareOption{reply}{\gdef\@arttype{Reply}}
\DeclareOption{retraction}{\gdef\@arttype{Retraction}}
\DeclareOption{review}{\gdef\@arttype{Review}}
\DeclareOption{perspective}{\gdef\@arttype{Perspective}} 
\DeclareOption{protocol}{\gdef\@arttype{Protocol}} 
\DeclareOption{shortnote}{\gdef\@arttype{Short Note}}
\DeclareOption{studyprotocol}{\gdef\@arttype{Study Protocol}}
\DeclareOption{supfile}{\gdef\@arttype{Supfile}}
\DeclareOption{systematicreview}{\gdef\@arttype{Systematic Review}}
\DeclareOption{technicalnote}{\gdef\@arttype{Technical Note}}
\DeclareOption{viewpoint}{\gdef\@arttype{Viewpoint}}
\DeclareOption{guidelines}{\gdef\@arttype{Guidelines}}
\DeclareOption{registeredreport}{\gdef\@arttype{Registered Report}}
\DeclareOption{tutorial}{\gdef\@arttype{Tutorial}}

%% To choose the status of the manuscript
\DeclareOption{submit}{\gdef\@status{submit}}
\DeclareOption{accept}{\gdef\@status{accept}}

%% To choose the whether there is one or more authors
\DeclareOption{oneauthor}{\gdef\@authornum{author}}
\DeclareOption{moreauthors}{\gdef\@authornum{authors}}

%% Add the chosen options to the class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

%% Defaults
\ExecuteOptions{notspecified,10pt,a4paper,article,submit,oneauthor}

%% Process options
\ProcessOptions\relax

%% MORE DECLARATIONS

%%%% Maths environments
\RequirePackage{amsthm}
\newtheoremstyle{Psp}% name
{12pt}% space above
{12pt}% space below
{\itshape}% body font
{}% indent amount 1
{\bfseries}% theorem head font
{.}% punctuation after theorem head
{.5em}% space after theorem head
{}% theorem head spec (can be left empty, meaning `normal')

\renewcommand{\qed}{\unskip\nobreak\quad\qedsymbol} %% This places the symbol right after the text instead of placing it at the end on the line.

\renewenvironment{proof}[1][\proofname]{\par %% \proofname allows to have "Proof of my theorem"
  \pushQED{\qed}%
  \normalfont \topsep6\p@\@plus6\p@\relax
  \trivlist
  \item[\hskip\labelsep
        \bfseries %% "Proof" is bold
    #1\@addpunct{.}]\ignorespaces %% Period instead of colon
}{%
  \popQED\endtrivlist\@endpefalse
}

 \theoremstyle{Psp}
 \newcounter{theorem}
 \setcounter{theorem}{0}
 \newtheorem{Theorem}[theorem]{Theorem}
 
 \newcounter{lemma}
 \setcounter{lemma}{0}
 \newtheorem{Lemma}[lemma]{Lemma}
 
 \newcounter{corollary}
 \setcounter{corollary}{0}
 \newtheorem{Corollary}[corollary]{Corollary}
 
 \newcounter{proposition}
 \setcounter{proposition}{0}
 \newtheorem{Proposition}[proposition]{Proposition}
 
 \newcounter{characterization}
 \setcounter{characterization}{0}
 \newtheorem{Characterization}[characterization]{Characterization}
 
 \newcounter{property}
 \setcounter{property}{0}
 \newtheorem{Property}[property]{Property}
 
 \newcounter{problem}
 \setcounter{problem}{0}
 \newtheorem{Problem}[problem]{Problem}
 
 \newcounter{example}
 \setcounter{example}{0}
 \newtheorem{Example}[example]{Example}
 
 \newcounter{examplesanddefinitions}
 \setcounter{examplesanddefinitions}{0}
 \newtheorem{ExamplesandDefinitions}[examplesanddefinitions]{Examples and Definitions}
 
 \newcounter{remark}
 \setcounter{remark}{0}
 \newtheorem{Remark}[remark]{Remark}
 
 \newcounter{definition}
 \setcounter{definition}{0}
 \newtheorem{Definition}[definition]{Definition}
 
 \newcounter{hypothesis}
 \setcounter{hypothesis}{0}
 \newtheorem{Hypothesis}[hypothesis]{Hypothesis}

 \newcounter{notation}
 \setcounter{notation}{0}
 \newtheorem{Notation}[notation]{Notation}
 
 \newcounter{assumption}
 \setcounter{assumption}{0}
 \newtheorem{Assumption}[assumption]{Assumption}
 
 % Define left/right mark in math environment
\let\originalleft\left
\let\originalright\right
\renewcommand{\left}{\mathopen{}\mathclose\bgroup\originalleft}
\renewcommand{\right}{\aftergroup\egroup\originalright}
 

%%%% References
%%%% vancouver style journals
\newcommand{\vancouverstylejournals}{
	\ifthenelse{ %
	   \equal{\@journal}{ges}
	\OR \equal{\@journal}{hpgg}
		}
}

%%%%% Hyperlinks
%% Define color for citations
\definecolor{bluecite}{HTML}{0875b7}

\ifthenelse{\equal{\@arttype}{Book}}{
	\RequirePackage[unicode=true,
	bookmarksopen={true},
	pdffitwindow=true, 
	colorlinks=true, 
	linkcolor=black, 
	citecolor=black, 
	urlcolor=black, 
	hyperfootnotes=false, 
	pdfstartview={FitH},
	pdfpagemode=UseNone]{hyperref}
	}{
	\RequirePackage[unicode=true,
	bookmarksopen={true},
	pdffitwindow=true, 
	colorlinks=true, 
	linkcolor=blue, 
	citecolor=blue, 
	urlcolor=blue, 
	hyperfootnotes=false, 
	pdfstartview={FitH},
	pdfpagemode= UseNone]{hyperref}
} 

%% To have the possibility to change the urlcolor
\newcommand{\changeurlcolor}[1]{\hypersetup{urlcolor=#1}} 


%%%% Metadata
\newcommand{\org@maketitle}{}% LATEX-Check
\let\org@maketitle\maketitle
\def\maketitle{%
	\hypersetup{
		pdftitle={\@Title},
		pdfsubject={\@abstract},
		pdfkeywords={\@keyword},
		pdfauthor={\@AuthorNames}
		}%
	\org@maketitle
}


%%%% Footnotes
\RequirePackage{scrextend}
\setlength{\skip\footins}{0.6cm} % Increase space between text and footnote
\setlength{\footnotesep}{10pt} % Increase space between line and footnote
\deffootnote{1.5em}{0em}{\textsuperscript{\thefootnotemark}\quad} % Remove indent
\renewcommand{\pcol@footnoterule}{% Kerns avoid vertical space
  \kern -3pt                         % This -3 is negative
  \hrule width .3\textwidth height 0.4pt % of the sum of this 1
  \kern 2pt}                         % and this 2
\footnotelayout{m} % At the end of the page, not at the end of the column


%%%% URL
\RequirePackage{url}
\urlstyle{same}
% Line breaks in URL
\def\UrlDigits{\do\1\do\2\do\3\do\4\do\5\do\6\do\7\do\8\do\9\do\0}
\g@addto@macro{\UrlBreaks}{\UrlOrds}
\g@addto@macro{\UrlBreaks}{\UrlDigits}


%%%% Widows & orphans
\clubpenalty=10000
\widowpenalty=10000
\displaywidowpenalty=10000


%%%% To avoid "Output-loop.." compile bug
\maxdeadcycles=10000

%%%% Front matter
% Command for checking for a question mark or exclamation mark in title
\def\instring#1#2{TT\fi\begingroup\edef\x{\endgroup\noexpand\in@{#1}{#2}}\x\ifin@}

\def\@linktojournal{}
\newcommand{\linktojournal}[1]{\gdef\@linktojournal{#1}}%
\newcommand{\journallink}{\@linktojournal}

\newcommand{\firstargument}{}
\newcommand{\Title}[1]{\gdef\@Title{#1}}%
\def\@TitleCitation{}
\newcommand{\TitleCitation}[1]{\gdef\@TitleCitation{#1}}%
\newcommand{\Author}[1]{\gdef\@Author{#1}}%
\def\@AuthorNames{}
\newcommand{\AuthorNames}[1]{\gdef\@AuthorNames{#1}}%
\def\@AuthorCitation{}
\newcommand{\AuthorCitation}[1]{\gdef\@AuthorCitation{#1}}%
\newcommand{\firstpage}[1]{\gdef\@firstpage{#1}}
\newcommand{\doinum}[1]{\gdef\@doinum{#1}}
\newcommand{\hreflink}[1]{\gdef\@hreflink{#1}}
\newcommand{\papercitation}{%
	\raggedright
	\hyphenpenalty=10000 % Cacel hyphenpent setting for citation
	\tolerance=100
	\vancouverstylejournals{%
	    \@AuthorCitation{}. %
		\@TitleCitation. % Remove period if title ends with ? or ! or ...
		{\@journalshort}. %
		{\@pubyear};%
{\@pubvolume}(\@issuenum):%
	}{%		
		\@AuthorCitation{}. %
		\@TitleCitation. % Remove period if title ends with ? or ! or ...
		%\textit
		{\@journalshort}. %
{\@pubyear};%
		\@pubvolume:%
	}
	\ifthenelse{\equal{\@continuouspages}{\@empty}}{%
\fivedigits\@articlenumber.
		}{%
		\@firstpage\ifnumcomp{\totvalue{page}-1}{=}{\@firstpage}{}{--\pageref*{LastPage}}. %
		}
	\changeurlcolor{black}%
	\href{https://doi.org/10.47248\@doinum}%
	{\@hreflink}
}
% DOI number
% Create command to add a leading zero if 1 digit
\newcommand\twodigits[1]{%
	\ifnum#1<10 %
		0\number#1
   	\else
		\number#1
	\fi
}

% Create command to add a leading zero if less then 5 digits
\newcommand\fivedigits[1]{%
	\ifnum#1<10 %
		000\number#1
	\else
		\ifnum#1<100 %
			00\number#1
		\else
			\ifnum#1<1000 %
				0\number#1
			\else
				\ifnum#1<10000 %
					\number#1
				\else
					\ifnum#1<100000 %
						\number#1
					\else
						error
					\fi
				\fi
			\fi
		\fi
	\fi
}



\ifthenelse{\equal{\@journal}{molbank}}{
	\doinum{10.47248/\@articlenumber}
	}{	\doinum{10.47248/\@doiabbr24\twodigits\@pubvolume\twodigits\@issuenum\fivedigits\@articlenumber}
}

% For \@pubvolume, \@issuenum, and \@articlenumber: create command to cut leading zeros
\newcommand\cutdigits[1]{%
	\ifnum#1>0 %
		\number#1 
	\else
		\ifnum#1<10000 %
			\number#1
		\else             
			error
		\fi
	\fi
}

\newcommand{\pubvolume}[1]{\gdef\@pubvolume{\cutdigits{#1}}}
\newcommand{\pubyear}[1]{\gdef\@pubyear{#1}}
\newcommand{\copyrightyear}[1]{\gdef\@copyrightyear{#1}}
\newcommand{\address}[2][]{\renewcommand{\firstargument}{#1}\gdef\@address{#2}}
\newcommand{\corresfirstargument}{}
\def\@corres{}
\newcommand{\corres}[2][]{\renewcommand{\corresfirstargument}{#1}\gdef\@corres{#2}} 
\def\@conference{}
\newcommand{\conference}[1]{\gdef\@conference{#1}}%
\def\@abstract{}
\renewcommand{\abstract}[1]{\gdef\@abstract{#1}}
%%%%%%%%%%%%%%%%%
\def\@background{}
\newcommand{\background}[1]{\gdef\@background{#1}}
\def\@methods{}
\newcommand{\methods}[1]{\gdef\@methods{#1}}
\def\@results{}
\newcommand{\results}[1]{\gdef\@results{#1}}
\def\@conclusions{}
\newcommand{\conclusions}[1]{\gdef\@conclusions{#1}}
%%%%%%%%%%%%%%%%%%%%%%
\def\@externaleditor{}
\newcommand{\externaleditor}[1]{\gdef\@externaleditor{#1}}
\def\@LSID{}
\newcommand{\LSID}[1]{\gdef\@LSID{#1}}
\newcommand{\datereceived}[1]{\gdef\@datereceived{#1}} 
\newcommand{\dateaccepted}[1]{\gdef\@dateaccepted{#1}} 
\newcommand{\datepublished}[1]{\gdef\@datepublished{#1}} 
\def\@pacs{}
\newcommand{\PACS}[1]{\gdef\@pacs{#1}} 
\def\@msc{}
\newcommand{\MSC}[1]{\gdef\@msc{#1}} 
\def\@jel{}
\newcommand{\JEL}[1]{\gdef\@jel{#1}}
\def\@keyword{}
\newcommand{\keyword}[1]{\gdef\@keyword{#1}}
\def\@dataset{}
\newcommand{\dataset}[1]{\gdef\@dataset{#1}}
\def\@datasetlicense{}
\newcommand{\datasetlicense}[1]{\gdef\@datasetlicense{#1}}
\def\@featuredapplication{}
\newcommand{\featuredapplication}[1]{\gdef\@featuredapplication{#1}}
\def\@keycontribution{}
\newcommand{\keycontribution}[1]{\gdef\@keycontribution{#1}}
\def\@encyclopediadef{}
\newcommand{\encyclopediadef}[1]{\gdef\@encyclopediadef{#1}}
\def\@issuenum{}
\newcommand{\issuenum}[1]{\gdef\@issuenum{\cutdigits{#1}}}
\def\@firstnote{}
\newcommand{\firstnote}[1]{\gdef\@firstnote{#1}}
\def\@secondnote{}
\newcommand{\secondnote}[1]{\gdef\@secondnote{#1}}%
\def\@thirdnote{}
\newcommand{\thirdnote}[1]{\gdef\@thirdnote{#1}}%
\def\@fourthnote{}
\newcommand{\fourthnote}[1]{\gdef\@fourthnote{#1}}%
\def\@fifthnote{}
\newcommand{\fifthnote}[1]{\gdef\@fifthnote{#1}}%
\def\@sixthnote{}
\newcommand{\sixthnote}[1]{\gdef\@sixthnote{#1}}%
\def\@seventhnote{}
\newcommand{\seventhnote}[1]{\gdef\@seventhnote{#1}}%
\def\@eighthnote{}
\newcommand{\eighthnote}[1]{\gdef\@eighthnote{#1}}%
\def\@correspond{}
\newcommand{\correspond}[1]{\gdef\@correspond{#1}}%
\def\@simplesumm{}
\newcommand{\simplesumm}[1]{\gdef\@simplesumm{#1}}
\newcommand{\articlenumber}[1]{
	\ifthenelse{\equal{\@journal}{molbank}}{
		\gdef\@articlenumber{#1}%
		}{
		\gdef\@articlenumber{\cutdigits{#1}}%
		}
	}

\def\@externalbibliography{}
\newcommand{\externalbibliography}[1]{\gdef\@externalbibliography{#1}}
\def\@reftitle{}
\newcommand{\reftitle}[1]{\gdef\@reftitle{#1}}


%% ORCID
% Make Orcid icon
\newcommand{\orcidicon}{\includegraphics[width=0.32cm]{Definitions/logo-orcid.eps}}

% Define link and button for each author
\foreach \x in {A, ..., Z}{%
\expandafter\xdef\csname orcid\x\endcsname{\noexpand\href{https://orcid.org/\csname orcidauthor\x\endcsname}{\noexpand\orcidicon}}
}


%%%% Journal name for the header
\newcommand{\journalname}{\@journalfull}
    
\regtotcounter{page} % To enable extracting the value of the counter "page" using the totcount package


%%%% Header and footer on first page
%% The plain page style needs to be redefined because with \maketitle in the article class, LaTeX applies the the plain page style automatically to the first page.
\ifthenelse{\equal{\@journal}{preprints} %
		\OR \equal{\@arttype}{Book}}{%
	\fancypagestyle{plain}{%
		\fancyhf{}
		\ifthenelse{\equal{\@arttype}{Book}}{
        			\fancyfoot[C]{\footnotesize\thepage}
     	   		}{%
     	   		\fancyfoot[R]{\footnotesize\thepage}
			}
		\fancyfoot[R]{
			\fontsize{8}{8}\selectfont
			{\changeurlcolor{black}%
			\url{\journallink}
			}}		
		}
	}{%
	\ifthenelse{\equal{\@arttype}{Supfile}}{
		\fancypagestyle{plain}{
			\fancyhf{}
			\fancyhead[R]{
				\footnotesize %
				S\thepage{} of S\pageref*{LastPage}%
				%\\
				\rule{\textwidth}{0.0pt}
				}%
			\fancyfoot[R]{
			\fontsize{8}{8}\selectfont
			{\changeurlcolor{black}%
			\url{\journallink}
			}}
			\fancyhead[L]{
				\footnotesize %
				\ifthenelse{\equal{\@status}{submit}}{%
					%Version {\@ \today} submitted to {\em \journalname}%
					~
					}{%
					%{\em \journalname} %
					%{\bfseries \@pubyear}, %
					%5{\em \@pubvolume}, %
					%\ifthenelse{\equal{\@continuouspages}{\@empty}}{%
					%	\@articlenumber%
					%	}{%
					%	S\@firstpage\ifnumcomp{\totvalue{page}-1}{=}{\@firstpage}{}{--S\pageref*{LastPage}}%
					%	}%
					%. {\changeurlcolor{black}%
        			%		\url{https://doi.org/\@doinum}}%
					}%
					\\\vspace{-2pt}\rule{\textwidth}{0.0pt}
				}%
			}%
		}{
		\fancypagestyle{plain}{
		\renewcommand{\footrulewidth}{0.0pt}
			\fancyhead{\null\vspace{8pt}}
			\fancyfoot[L]{
			\fontsize{8}{8}\selectfont
			\ifthenelse{\equal{\@status}{submit}}{%
				%Version {\@ \today} submitted to {\em \journalname}%
				}{%
				%{\em\journalname\ }{\bfseries\@pubyear}, {\em \@pubvolume}, %
				%\ifthenelse{\equal{\@continuouspages}{\@empty}}{%
				%	\@articlenumber. %
				%	}{%
				%	\@firstpage\ifnumcomp{\totvalue{page}-1}{=}{\@firstpage}{}{--\pageref*{LastPage}}. %
				%	}%
				%	{\changeurlcolor{black}%
				%	\url{https://doi.org/\@doinum}
				%	}
				}%
			}
			\fancyfoot[R]{
			\fontsize{8}{8}\selectfont
			{\changeurlcolor{black}%
			%\url{\journallink}
			}
			}
			}
		}%
	}%	


%%%% Maketitle part 1: Logo, Arttype, Title, Author
\renewcommand{\@maketitle}{
	\begin{flushleft}
	\ifthenelse{\equal{\@arttype}{Supfile}}{%
		\fontsize{18}{18}\selectfont
		\raggedright
		\hyphenpenalty=10000
		\tolerance=1000
		\noindent\textbf{Supplementary Materials: \@Title}%
		\par
		\vspace{12pt}
		\fontsize{10}{10}\selectfont
		\noindent\boldmath\bfseries{\@Author}
		}{%
		\ifthenelse{\equal{\@arttype}{Book}}{}{%
			\vspace*{-1.75cm}
            \textit{\footnotesize \@journalfull}\par
            \vspace{-2em}
            \footnotesize DOI: \@doinum
			}
		{%0
		\ifthenelse{\equal{\@journal}{preprints}
			\OR \equal{\@arttype}{Book}}{}{%
				\ifthenelse{\equal{\@status}{submit}}{%	
					\hfill \includegraphics[height=1cm]{LOGO}%%
					}{
					    %\@journalfull
					%\includegraphics[height=1.2cm]{LOGO}%%
					\hfill
					\ifthenelse{\equal{\@journal}{proceedings}}{
						\includegraphics[height=1.2cm]{LOGO}%%
						}{}
					\ifthenelse{\equal{\@journal}{scipharm}}{%
						\includegraphics[height=1cm]{LOGO}%
						}{%
					    \includegraphics[height=1cm]{LOGO}%
						}%
					}%
					\par
					\vspace{-1em}
					\rule{\textwidth}{0.0pt} %% rule of title head
			}%
		\par
		}%0
		{%1
    		\vspace{14pt}
    		\fontsize{10}{10}\selectfont
		\ifthenelse{\equal{\@arttype}{Book}}{}{
			%\textit{
			\@arttype %}%
			}%	
 	   	        \par%
    		}%1
    		{%2
   	 %	\vspace{8pt}
  	  	\fontsize{14.5}{17}\selectfont
		\hyphenpenalty=10000
		\tolerance=1000
   	 	\boldmath\bfseries{\@Title}
   	 	\par
   	 	\vspace{12pt}
   	 	}%2
   		{%3
		\hyphenpenalty=10000
		\tolerance=1000
    		\fontsize{11}{12}\selectfont%
    		{\boldmath\@Author}%\par
    		}%3
		}
	\end{flushleft}%
	\vspace{-24pt}
	}

% Commands for hanging indent
\newcommand{\dist}{1.7em}
\newcommand{\hang}{\hangafter=1\hangindent=\dist\noindent}


%%%% Maketitle part 2
\newcommand{\maketitlen}{ 
	\columnratio{0.23} % (textwidth 18.53 cm + margins 2x1.27 = 21.07 = A4) 4.6 cm indent is 1/4 of the textwidth
	\begin{paracol}{2}
	\ifthenelse{\equal{\@arttype}{Book}}{\vspace{12pt}\switchcolumn}{
		\vfill
		\begin{flushleft}
		\linespread{1.5} 
		\fontsize{9.03}{9}\selectfont
		\ifthenelse{\equal{\@status}{submit}}{%		
			}{	}
			%\textbf{Citation: }\papercitation
			\par\vspace{12pt}
			\ifthenelse{\equal{\@externaleditor}{\@empty}}{}{%
				\hyphenpenalty=10000
               			\tolerance=1000
				\@externaleditor\\
				}
            \textbf{Received:} \@datereceived\\
            \textbf{Accepted:} \@dateaccepted\\
            \textbf{Published:} \@datepublished
			\par\vspace{12pt}
			%%%%%%%%%%%%%%%%%%%%
			\linespread{1.5} 
			\fontsize{9.03}{9}\selectfont
			\emergencystretch 3em\noindent\cright
			%%%%%%%%%%%%%%%%%%%
			\par\vspace{12pt}
			\emergencystretch 2em\noindent\textbf{Publisher's Note:} \\
			Pivot Science Publications remains neutral with regard to jurisdictional claims in published maps and institutional affiliations.
			\par%\vspace{-12pt}
		\end{flushleft}%
	\switchcolumn	
	\begin{flushleft}
	\begin{spacing}{1.25}
	\hyphenpenalty=10000
	\tolerance=1000
	\setlength{\parskip}{12pt}
	\fontsize{11}{12}\selectfont
	{%
	\ifthenelse{\equal{\firstargument}{1}}{}{%
	\hang}\@address
	\par
	}%
	{%
	\ifthenelse{\equal{\@authornum}{author}}{}{%
	\ifthenelse{\equal{\@corres}{\@empty}}{}{%
	\hang\textbf{*}  \@corres}
	\par
	}
	}%
	{%
	\ifthenelse{\equal{\@conference}{\@empty}}{}{%
	\hang$\dagger$  This paper is an extended version of our paper published in\space \@conference.}
	\par
	}%
	{%
	\ifthenelse{\equal{\@firstnote}{\@empty}}{}{%
	\hang\ifthenelse{\equal{\@conference}{\@empty}}{$\dagger$}{$\ddagger$} \@firstnote}	
	\par
	}%
	{%
	\ifthenelse{\equal{\@secondnote}{\@empty}}{}{%
	\hang \ifthenelse{\equal{\@conference}{\@empty}}{$\ddagger$}{\S} \@secondnote}
	\par
	}%
	{%
	\ifthenelse{\equal{\@thirdnote}{\@empty}}{}{%
	\hang \ifthenelse{\equal{\@conference}{\@empty}}{\S}{$\|$}  \@thirdnote}
	\par
	}%
	{%
	\ifthenelse{\equal{\@fourthnote}{\@empty}}{}{%
	\hang \ifthenelse{\equal{\@conference}{\@empty}}{$\|$}{\P}  \@fourthnote}
	\par
	}%
	{%
	\ifthenelse{\equal{\@fifthnote}{\@empty}}{}{%
	\hang \ifthenelse{\equal{\@conference}{\@empty}}{\P}{**}  \@fifthnote}
	\par
	}%
	{%
	\ifthenelse{\equal{\@sixthnote}{\@empty}}{}{%
	\hang \ifthenelse{\equal{\@conference}{\@empty}}{**}{$\dagger\dagger$}  \@sixthnote}
	\par
	}%
	{%
	\ifthenelse{\equal{\@seventhnote}{\@empty}}{}{%
	\hang \ifthenelse{\equal{\@conference}{\@empty}}{$\dagger\dagger$}{$\ddagger\ddagger$}  \@seventhnote}
	\par
	}%
	{%
	\ifthenelse{\equal{\@eighthnote}{\@empty}}{}{%
	\hang \ifthenelse{\equal{\@conference}{\@empty}}{$\ddagger\ddagger$}{***}  \@eighthnote}
	\par
	}%
	{%
	\ifthenelse{\equal{\@correspond}{\@empty}}{}{%
        \hang \ifthenelse{\equal{\@conference}{\@empty}}{$^*$}{***}  \textbf{Correspondence:} \@correspond}
	\par
	}
	\end{spacing}
	\end{flushleft}
}
}

%%%% Abstract, keywords, journal data, PACS, MSC, JEL
\newcommand{\abstractkeywords}{
    \linespread{1.25}
    \setlength{\parskip}{6pt}
    \fontsize{11}{12}\selectfont
\vspace{-4.5em}\vspace{24pt}
\noindent{\color{yellow}{\rule{\linewidth}{1.5pt}}}\par
%\vspace{4pt}

\ifthenelse{\equal{\@abstract}{\@empty}}{}{
	\noindent\textbf{Abstract\space}\\ \@abstract\par
	}

\ifthenelse{\equal{\@keyword}{\@empty}}{}{
	\noindent\textbf{Keywords:\space}\@keyword
	\par
	}

\vspace{-8pt}
\ifthenelse{\equal{\@arttype}{Book}}{}{%
    \noindent {\color{yellow}{\rule{\linewidth}{1.5pt}}}
    }
\normalsize
\vspace{-1em}
}


%%%% Print maketitle and abstractkeywords
\ifthenelse{\equal{\@arttype}{Supfile}}{
	\AfterEndPreamble{
	\maketitle
	\let\maketitle\relax
	\columnratio{0.23} % (textwidth 18.53 cm + margins 2x1.27 = 21.07 = A4) 4.6 cm indent is 1/4 of the textwidth
	\begin{paracol}{2}
	\switchcolumn
	\ifthenelse{\equal{\@status}{submit}}{\linenumbers}{}
	}%
	}{
	\AfterEndPreamble{
	\maketitle
	\let\maketitle\relax
	\maketitlen
	\let\maketitlen\relax
	\ifthenelse{\equal{\@status}{submit}}{\linenumbers}{}
	\abstractkeywords
}%
	}
\AtBeginDocument{
	\DeclareSymbolFont{AMSb}{U}{msb}{m}{n}
	\DeclareSymbolFontAlphabet{\mathbb}{AMSb}
	}


%%%% Font size in Tables
\AtEndPreamble{
	\def\@tablesize{}
	\newcommand{\tablesize}[1]{\gdef\@tablesize{#1}}
	\let\oldtabularx\tabularx
	\renewcommand{\tabularx}{\ifthenelse{\equal{\@tablesize}{\@empty}}{\small}{\@tablesize}\oldtabularx}
}


%%%% Section headings
\setcounter{secnumdepth}{4} % Default: 3 in the article class. To get paragraphs numbered and counted, increase the default value of secnumdepth to 4

\titleformat {\section} [block] {\raggedright \fontsize{12.05}{15.35}\selectfont\bfseries} {\thesection.\space} {2pt} {}
\titlespacing {\section} {0pt} {12pt} {3pt}

\titleformat {\subsection} [block] {\raggedright \fontsize{11}{11}\selectfont\bfseries} {\thesubsection\space} {2pt} {}
\titlespacing {\subsection} {0pt} {12pt} {3pt}

\titleformat {\subsubsection} [block] {\raggedright \fontsize{11}{11}\selectfont\itshape} {\thesubsubsection\space} {2pt} {}
\titlespacing {\subsubsection} {0pt} {12pt} {3pt}

\titleformat {\paragraph} [block] {\raggedright \fontsize{11}{11}\selectfont} {} {0pt} {}
\titlespacing {\paragraph} {0pt} {12pt} {3pt}


%%%% Special section title style for back matter
\newcommand{\supplementary}[1]{
%\par\vspace{6pt}\noindent{\fontsize{9}{11.5}\selectfont\textbf{Supplementary Materials:} {#1}\par}}
    \section*{Supplementary Materials}
        #1
}

\newcommand{\authorcontributions}[1]{%
%\vspace{6pt}\noindent{\fontsize{9}{11.2}\selectfont\textbf{Author Contributions:} {#1}\par}}
    \section*{Author Contributions}
    #1
}

\newcommand{\funding}[1]{
%\vspace{6pt}\noindent{\fontsize{9}{11.2}\selectfont\textbf{Funding:} {#1}\par}}
    \section*{Funding}
        #1
}

\newcommand{\institutionalreview}[1]{
%\vspace{6pt}\noindent{\fontsize{9}{11.2}\selectfont\textbf{Institutional Review Board Statement:} {#1}\par}}
    \section*{Ethics Statement}
    #1
}

\newcommand{\informedconsent}[1]{
%\vspace{6pt}\noindent{\fontsize{9}{11.2}\selectfont\textbf{Informed Consent Statement:} {#1}\par}}
    \section*{Consent for Publication}
    #1
}

\newcommand{\dataavailability}[1]{
%%\vspace{6pt}\noindent{\fontsize{9}{11.2}\selectfont\textbf{Data Availability Statement:} {#1}\par}}
	\section*{Availability of Data and Material}
#1
}

\newcommand{\acknowledgments}[1]{
%%\vspace{6pt}\noindent{\fontsize{9}{11.2}\selectfont\textbf{Acknowledgments:} {#1}\par}}
	\section*{Acknowledgments}
#1
}

\newcommand{\orcidstate}[1]{
	\section*{ORCID}
#1
}

\newcommand{\graphicabstract}[1]{
	\section*{Graphic Abstract}
#1
}

\newcommand{\conflictsofinterest}[1]{%
%%\vspace{6pt}\noindent{\fontsize{9}{11.2}\selectfont\textbf{Conflicts of Interest:} {#1}\par}}
	\section*{Competing Interests}
#1
}

\newcommand{\sampleavailability}[1]{%
%%\vspace{6pt}\noindent{\fontsize{9}{11.2}\selectfont\textbf{Sample Availability:} {#1}\par}}
	\section*{Sample Availability}
#1
}


\newcommand{\abbreviations}[1]{%
%\vspace{12pt}\noindent{\selectfont\textbf{Abbreviations}\par\vspace{3pt}\noindent {\fontsize{9}{11.2}\selectfont #1}\par}
    \section*{Abbreviations}
    #1
}


%%%%% Defines the appendix
\def\@appendixtitles{}
\newcommand{\appendixtitles}[1]{\gdef\@appendixtitles{#1}}

\def\@appendixsections{}
\newcommand{\appendixsections}[1]{\gdef\@appendixsections{#1}}

\def\@appendixstart{}
\newcommand{\appendixstart}[1]{\gdef\@appendixstart{#1}}

\renewcommand{\appendixstart}{%
\setcounter{section}{0}%
\setcounter{subsection}{0}%
\setcounter{subsubsection}{0}%
\setcounter{figure}{0}
\setcounter{specialtable}{0}
\setcounter{scheme}{0}
\setcounter{chart}{0}
\setcounter{boxenv}{0}
\setcounter{equation}{0}
\setcounter{theorem}{0}
\setcounter{lemma}{0}
\setcounter{corollary}{0}
\setcounter{proposition}{0} 
\setcounter{characterization}{0} 
\setcounter{property}{0} 
\setcounter{problem}{0} 
\setcounter{example}{0} 
\setcounter{examplesanddefinitions}{0} 
\setcounter{remark}{0} 
\setcounter{definition}{0} 
\setcounter{hypothesis}{0}
\setcounter{notation}{0}

%% Continuous counter for paracol columns
\globalcounter{figure}
\globalcounter{specialtable}
\globalcounter{scheme}
\globalcounter{chart}
\globalcounter{boxenv}
\globalcounter{equation}
\globalcounter{theorem}
\globalcounter{lemma}
\globalcounter{corollary}
\globalcounter{proposition}
\globalcounter{characterization}
\globalcounter{property}
\globalcounter{problem}
\globalcounter{example}
\globalcounter{examplesanddefinitions}
\globalcounter{remark}
\globalcounter{definition}
\globalcounter{hypothesis}
\globalcounter{notation}
}

\renewcommand{\appendix}{%
%
\gdef\thesection{\@Alph\c@section}%
\gdef\thesubsection{\@Alph\c@section.\@arabic\c@subsection}%
%	
\titleformat {\section} [block] {\raggedright\bfseries} {%
	\ifthenelse{\equal{\@appendixtitles}{yes}}{%
		\appendixname~\thesection.%
		}{%
		\appendixname~\thesection~%
		}
	} {0pt} {}
\titlespacing {\section} {0pt} {12pt} {3pt}
%
\titleformat {\subsection} [block] {\raggedright\itshape} {%
	\ifthenelse{\equal{\@appendixtitles}{yes}}{%
		\appendixname~\thesubsection.%
		}{%
		\appendixname~\thesubsection%
		}
	} {0pt} {}
\titlespacing {\section} {0pt} {12pt} {3pt}
%
\titleformat {\subsubsection} [block] {\raggedright\selectfont} {%
	\ifthenelse{\equal{\@appendixtitles}{yes}}{%
		\appendixname~\thesubsubsection.%
		}{%
		\appendixname~\thesubsubsection%
		}
	} {0pt} {}
\titlespacing {\section} {0pt} {12pt} {3pt}
%
\gdef\theHsection{\@Alph\c@section.}% for hyperref
\gdef\theHsubsection{\@Alph\c@section.\@arabic\c@subsection}% for hyperref
\csname appendixmore\endcsname
\renewcommand{\thefigure}{A\arabic{figure}}
\renewcommand{\thespecialtable}{A\arabic{specialtable}}
\renewcommand{\thescheme}{A\arabic{scheme}}
\renewcommand{\thechart}{A\arabic{chart}}
\renewcommand{\theboxenv}{A\arabic{boxenv}}
\renewcommand{\theequation}{A\arabic{equation}}
\renewcommand{\thetheorem}{A\arabic{theorem}}
\renewcommand{\thelemma}{A\arabic{lemma}}
\renewcommand{\thecorollary}{A\arabic{corollary}}
\renewcommand{\theproposition}{A\arabic{proposition}} 
\renewcommand{\thecharacterization}{A\arabic{characterization}}
\renewcommand{\theproperty}{A\arabic{property}}
\renewcommand{\theproblem}{A\arabic{problem}}
\renewcommand{\theexample}{A\arabic{example}}
\renewcommand{\theexamplesanddefinitions}{A\arabic{examplesanddefinitions}}
\renewcommand{\theremark}{A\arabic{remark}}
\renewcommand{\thedefinition}{A\arabic{definition}}
\renewcommand{\thehypothesis}{A\arabic{hypothesis}}
\renewcommand{\thenotation}{A\arabic{notation}}
}


%%%% Layout
\ifthenelse{\equal{\@arttype}{Book}}{%%
	\RequirePackage[left=2.05cm,
					right=2.05cm,
					top=1.9cm,
					bottom=2.05cm,
					paperwidth=170mm,
					paperheight=244mm,
					footskip=20pt,
					headsep=20pt,
					includehead, 
					includefoot]{geometry}
	}{
	\RequirePackage[left=1.27cm,
				right=1.27cm,
				top=1.9cm,
				bottom=1.75cm,
				footskip=48pt,
				headsep=20pt,
				includehead,
				includefoot]{geometry}
	}

\linespread{1.25} 
\setlength{\parindent}{0pt} %{0.75cm}
%\setlength{\parskip}{0.em}
\ifthenelse{\equal{\@status}{submit}}{\setlength{\columnsep}{1cm}}{\setlength{\columnsep}{0.5cm}} % Distance between the two columns on the first page

%%%% Commands for landscape page
\newcommand{\startlandscape}{
	\end{paracol}
	\clearpage
	\paperwidth=\pdfpageheight
	\paperheight=\pdfpagewidth
	\pdfpageheight=\paperheight
	\pdfpagewidth=\paperwidth
	\newgeometry{layoutwidth=297mm,layoutheight=210 mm, left=1.27cm,right=1.27cm,top=1.8cm,bottom=0.6cm, includehead,includefoot}
	\fancyheadoffset{0pt}
}

\newcommand{\finishlandscape}{
	\clearpage
	\paperwidth=\pdfpageheight
	\paperheight=\pdfpagewidth
	\pdfpageheight=\paperheight
	\pdfpagewidth=\paperwidth
	\restoregeometry
	\begin{paracol}{2}
	\switchcolumn
	\ifthenelse{\equal{\@status}{submit}}{\linenumbers}{}
}


%%%% Figures and tables
\RequirePackage{newfloat}
\DeclareFloatingEnvironment[]{listing}
\DeclareFloatingEnvironment[name=Box]{boxenv}	
\DeclareFloatingEnvironment[]{chart}
\DeclareFloatingEnvironment[]{scheme}
\DeclareFloatingEnvironment[]{figurewide}
\DeclareFloatingEnvironment[name=Table]{specialtable}

\RequirePackage{caption} 
\captionsetup[figure]{position=bottom, 	labelfont={bf, small, stretch=1.17}, labelsep=space, textfont={small, stretch=1.17}, aboveskip=6pt, belowskip=-6pt, singlelinecheck=off, justification=raggedright}

\captionsetup[table]{position=top, 	labelfont={bf, small, stretch=1.17}, labelsep=space, textfont={small, stretch=1.17}, aboveskip=6pt, belowskip=-6pt, singlelinecheck=off, justification=raggedright}

\captionsetup[scheme]{position=bottom,	labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, belowskip=-6pt, singlelinecheck=off, justification=raggedright}

\captionsetup[listing]{position=top, 		labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, singlelinecheck=off, justification=justified}

\captionsetup[chart]{position=bottom, 	labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, belowskip=-6pt, singlelinecheck=off, justification=justified}

\captionsetup[specialtable]{position=top, 		labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, singlelinecheck=off, justification=justified}

\captionsetup[boxenv]{position=top, 		labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, singlelinecheck=off, justification=justified}


\newcommand{\widefigure}{\captionsetup{position=bottom, margin=0.75cm, labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, belowskip=-6pt, singlelinecheck=on, justification=raggedright}
\centering
}

\newcommand{\widetable}{\captionsetup{position=top, margin=0.75cm, labelfont={bf, small, stretch=1.17}, labelsep=period, textfont={small, stretch=1.17}, aboveskip=6pt, singlelinecheck=on, justification=raggedright}
\centering
}

%% Continuous counter for paracol columns
\globalcounter{figure}
\globalcounter{specialtable}
\globalcounter{scheme}
\globalcounter{chart}
\globalcounter{boxenv}
\globalcounter{equation}
\globalcounter{theorem}
\globalcounter{lemma}
\globalcounter{corollary}
\globalcounter{proposition}
\globalcounter{characterization}
\globalcounter{property}
\globalcounter{problem}
\globalcounter{example}
\globalcounter{examplesanddefinitions}
\globalcounter{remark}
\globalcounter{definition}
\globalcounter{hypothesis}
\globalcounter{notation}

%% For table footnotes
\newsavebox{\@justcentbox}
\newcommand{\justifyorcenter}[1]{
\sbox \@justcentbox{#1}
\ifdim \wd \@justcentbox >\hsize #1
\else \centerline{#1} \fi
}


%%%% Bullet lists
\setitemize{topsep=3pt,parsep=0pt,itemsep=0pt,leftmargin=*,labelsep=5.5mm,align=parleft}
\setenumerate{topsep=3pt,parsep=0pt,itemsep=0pt,leftmargin=*,labelsep=5.5mm,align=parleft}
\setlist[description]{itemsep=0mm}


%%%% Quote environment
\renewenvironment{quote}{
	\list{}{
		\listparindent=0pt
		\leftmargin=0.75cm
		\rightmargin=0.75cm
		\topsep=3pt
		\parsep=3pt
	}%
	\item\relax
	}
	{\endlist}

%%%% Supplementary file
\ifthenelse{\equal{\@arttype}{Supfile}}{
	\renewcommand{\thefigure}{S\arabic{figure}}%
	\renewcommand{\thespecialtable}{S\arabic{table}}%
	}{}%

%% Link to supplementary material: www.Psp.com/ISSN-number/volume-number/issue-number/article-number	
\newcommand{\linksupplementary}[1]{\url{https://www.psp.com/\@ISSN/\@pubvolume/\@issuenum/\@articlenumber/#1}}


%%%% Header and footer (all pages except the first)
\renewcommand\headrule{} %% set line (from fancyhdr) in header to nothing

\pagestyle{fancy}
\lhead{
	\ifthenelse{\equal{\@journal}{preprints}%
	\OR \equal{\@arttype}{Book}}{%
		}{%
		\fontsize{8}{8}\selectfont%
		\ifthenelse{\equal{\@status}{submit}}{%
			%Version {\@ \today} submitted to {\em \journalname}%
            \textbf{\journalname}, \@pubyear;\@pubvolume(\@issuenum):\fivedigits\@articlenumber
			}{%
			\ifthenelse{\equal{\@arttype}{Supfile}}{%
			{\bfseries \journalname}, \@pubyear;\@pubvolume:%
			\ifthenelse{\equal{\@continuouspages}{\@empty}}{%
				\@articlenumber. %
				}{%
				S\@firstpage\ifnumcomp{\totvalue{page}-1}{=}{\@firstpage}{}{--S\pageref*{LastPage}}. %
				}%
			{\changeurlcolor{black}%
        			\url{https://doi.org/\@doinum}}%
			}{%
			{\bfseries \journalname}, \@pubyear;\@pubvolume%
			%\ifthenelse{\equal{\@continuouspages}{\@empty}}{%
			(\@issuenum):\fivedigits\@articlenumber%
			%	}{}%
			}%
			}\\%
			\rule{\textwidth}{0.0pt} %%% ekli
		}%
	}
	
\rhead{%
\ifthenelse{\equal{\@arttype}{Book}}{}{%
	\ifthenelse{\equal{\@arttype}{Supfile}}{%
		\fontsize{8}{8}\selectfont The~S\thepage{} of S\pageref*{LastPage}%
		}{%
		\ifthenelse{\equal{\@continuouspages}{\@empty}}{%
			\fontsize{8}{8}\selectfont Page \thepage{} of \pageref*{LastPage}%
			}{%
			\fontsize{8}{8}\selectfont\thepage%
		}%
		}\\%
		\rule{\textwidth}{0.0pt}
	}%
}

\cfoot{
	\ifthenelse{\equal{\@arttype}{Book}}{%
		\fontsize{8}{8}\selectfont\thepage
		}{%
		\fancyfoot[R]{
			\fontsize{8}{8}\selectfont
			{
			\changeurlcolor{black}%
			\url{\journallink}
			}}
	}
}


%%%% Article type "Retraction"
\ifthenelse{\equal{\@arttype}{Retraction}}{%%
	\def\@retractiondate{}% Date that the retraction notice was published
	\newcommand{\retractiondate}[1]{\gdef\@retractiondate{#1}}
	\def\@retractionnoticeyear{}% Year in which the retraction notice was published
	\newcommand{\retractionnoticeyear}[1]{\gdef\@retractionnoticeyear{#1}}
	\def\@retractionnoticevolume{} % Volume in which the retraction notice was published
	\newcommand{\retractionnoticevolume}[1]{\gdef\@retractionnoticevolume{#1}}
	\def\@retractionnoticeidnumber{}% Article Number in which the retraction notice was published
	\newcommand{\retractionnoticeidnumber}[1]{\gdef\@retractionnoticeidnumber{#1}}
	\def\@retractionnoticedoi{}  % DOI published retraction notice
	\newcommand{\retractionnoticedoi}[1]{\gdef\@retractionnoticedoi{#1}}
	\RequirePackage{draftwatermark}
	\SetWatermarkText{RETRACTED}
	\SetWatermarkScale{0.8}
	\fancypagestyle{plain}{
	\fancyhf{}
	\fancyfoot[L]{
		\footnotesize%
		\st{\mbox{\textit{\journalname} \textbf{\@pubyear};\textit\@pubvolume:}}%
		\ifthenelse{\equal{\@continuouspages}{\@empty}}{%
\st{\@articlenumber}%
			}{%
			\st{\@firstpage}\ifnumcomp{\totvalue{page}-1}{=}{\@firstpage}{}{\st{--\mbox{\pageref*{LastPage}}}}%
			}%
		\st{. {\changeurlcolor{black}%
		\href{https://doi.org/\@doinum}%
		{https://doi.org/\@doinum}}}%
		\\This paper has been retracted. A retraction notice was published on \@retractiondate{} %
		in \textit{\@journalfull} \textbf{\@retractionnoticeyear}, \textit{\@retractionnoticevolume}, \@retractionnoticeidnumber. https://doi.org/\@retractionnoticedoi
	}%
	\fancyfoot[R]{
		\footnotesize%
		{\changeurlcolor{black}%
		%\href{http://www.Psp.com/journal/\@journal}%
		%{www.psp.com/journal/\@journal}
		}%
	}%
	\renewcommand{\footrulewidth}{0.0pt}%
	}
}{}


%%%% Bibliography
%\renewcommand\bibname{References} % Backwards compatibility for book production
\renewcommand\@biblabel[1]{#1.\hfill}
\def\thebibliography#1{
\emergencystretch 2em
\section*{\@reftitle}
\addcontentsline{toc}{section}{References}
%\fontsize{11}{11}\selectfont
\list{{\arabic{enumi}.\,\,}}{\def\makelabel##1{\hss{##1}}
\topsep=0\p@
\parsep=0\p@
\partopsep=0\p@
\itemsep=0\p@
\labelsep=1.5mm
\vancouverstylejournals{%
	\ifthenelse{\equal{\@externalbibliography}{\@empty}}{%
		}{ }%
		}{%
	\itemindent=0\p@}
\settowidth\labelwidth{\footnotesize[#1]}%
\leftmargin\labelwidth
\advance\leftmargin\labelsep
\usecounter{enumi}}
}
\let\endthebibliography=\endlist


%%%% Copyright info
\newcommand{\cright}{%
			\textbf{Copyright: }\\
			\copyright{} {\@ \the\year} %by the \@authornum. %
			by the author(s).
            This is an Open Access article distributed under the terms of the 
            \href{https://creativecommons.org/licenses/by/4.0/}{\uline{Creative Commons License Attribution 4.0 International (CC BY 4.0)}}, which permits unrestricted use, distribution, and reproduction in any medium or format, provided the original work is correctly credited.
	}
	
%%%% For tables XML2PDF
\RequirePackage{seqsplit} % Use for split table column
  \newlength{\cellWidtha}
  \newlength{\cellWidthb}
  \newlength{\cellWidthc}
  \newlength{\cellWidthd}
  \newlength{\cellWidthe}
  \newlength{\cellWidthf}
  \newlength{\cellWidthg}
  \newlength{\cellWidthh}
  \newlength{\cellWidthi}
  \newlength{\cellWidthj}
  \newlength{\cellWidthk}
  \newlength{\cellWidthl}
  \newlength{\cellWidthm}
  \newlength{\cellWidthn}
  \newlength{\cellWidtho}
  \newlength{\cellWidthp}
  \newlength{\cellWidthq}
  \newlength{\cellWidthr}
  \newlength{\cellWidths}
  \newlength{\cellWidtht}
  \newlength{\cellWidthu}
  \newlength{\cellWidthv}
  \newlength{\cellWidthw}
  \newlength{\cellWidthx}
  \newlength{\cellWidthy}
  \newlength{\cellWidthz}
  \newlength{\cellWidthA}
  \newlength{\cellWidthB}
  \newlength{\cellWidthC}
  \newlength{\cellWidthD}
  \newlength{\cellWidthE}
  \newlength{\cellWidthF}
  \newlength{\cellWidthG}
  \newlength{\cellWidthH}
  \newlength{\cellWidthI}
  \newlength{\cellWidthJ}
  \newlength{\cellWidthK}
  \newlength{\cellWidthL}
  \newlength{\cellWidthM}
  \newlength{\cellWidthN}
  \newlength{\cellWidthO}
  \newlength{\cellWidthP}
  \newlength{\cellWidthQ}
  \newlength{\cellWidthR}
  \newlength{\cellWidthS}
  \newlength{\cellWidthT}
  \newlength{\cellWidthU}
  \newlength{\cellWidthV}
  \newlength{\cellWidthW}
  \newlength{\cellWidthX}
  \newlength{\cellWidthY}
  \newlength{\cellWidthZ}
 \newcommand{\PreserveBackslash}[1]{\let\temp=\\#1\let\\=\temp} % For table column setting in XML2PDF

\newcommand{\citethispaper}{\textbf{Cite this article:\space}\papercitation}
\endinput
